@@ -48,7 +48,8 @@ PlaylistSplitter::PlaylistSplitter(QWidget *parent, const char *name) :
     m_playlistBox(0),
     m_searchWidget(0),
     m_playlistStack(0),
-    m_editor(0)
+    m_editor(0),
+    m_nowPlaying(0)
 {
     setObjectName(name);
 
@@ -64,6 +65,12 @@ PlaylistSplitter::~PlaylistSplitter()
 {
     saveConfig();
 
+    // NowPlaying depends on the PlaylistCollection, so kill it now.
+    delete m_nowPlaying;
+    m_nowPlaying = 0;
+
+    delete m_searchWidget; // Take no chances here either.
+
     // Since we want to ensure that the shutdown process for the PlaylistCollection
     // (a base class for PlaylistBox) has a chance to write the playlists to disk
     // before they are deleted we're explicitly deleting the PlaylistBox here.
@@ -194,7 +201,7 @@ void PlaylistSplitter::setupLayout()
     connect(CollectionList::instance(), SIGNAL(signalCollectionChanged()),
             m_editor, SLOT(slotUpdateCollection()));
 
-    NowPlaying *nowPlaying = new NowPlaying(top, m_playlistBox);
+    m_nowPlaying = new NowPlaying(top, m_playlistBox);
 
     // Create the search widget -- this must be done after the CollectionList is created.
 
@@ -212,7 +219,7 @@ void PlaylistSplitter::setupLayout()
     connect(ActionCollection::action<KToggleAction>("showSearch"), SIGNAL(toggled(bool)),
             m_searchWidget, SLOT(setEnabled(bool)));
 
-    topLayout->addWidget(nowPlaying);
+    topLayout->addWidget(m_nowPlaying);
     topLayout->addWidget(m_searchWidget);
     topLayout->addWidget(m_playlistStack, 1);
 
