@@ -15,18 +15,21 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
-#include <qlayout.h>
-#include <qcheckbox.h>
-#include <qcombobox.h>
-#include <qspinbox.h>
-#include <qlineedit.h>
+#include "kcmcddb.h"
+#include "cddbconfigwidget.h"
+
+#include "libkcddb/lookup.h"
+#include "libkcddb/cache.h"
+#include "libkcddb/submit.h"
+
+#include <QCheckBox>
 #include <qradiobutton.h>
-#include <qlistbox.h>
-#include <qlabel.h>
-#include <qbuttongroup.h>
+#include <q3listbox.h>
+#include <q3buttongroup.h>
+#include <QVBoxLayout>
 
 #include <kconfig.h>
 #include <klocale.h>
@@ -35,21 +38,15 @@
 #include <kmessagebox.h>
 #include <kconfigdialogmanager.h>
 
-#include "cddbconfigwidget.h"
+K_PLUGIN_FACTORY(KCDDBFactory, registerPlugin<CDDBModule>();)
+K_EXPORT_PLUGIN(KCDDBFactory( "kcmcddb" ))
 
-#include "kcmcddb.h"
-#include "libkcddb/lookup.h"
-#include "libkcddb/cache.h"
-#include "libkcddb/submit.h"
 
-typedef KGenericFactory<CDDBModule, QWidget> KCDDBFactory;
-K_EXPORT_COMPONENT_FACTORY ( kcm_cddb, KCDDBFactory( "kcmcddb" ) )
-
-CDDBModule::CDDBModule(QWidget *parent, const char *name, const QStringList &)
-  : KCModule(parent, name)
+CDDBModule::CDDBModule(QWidget *parent, const QVariantList &)
+  : KCModule(KCDDBFactory::componentData(), parent)
 {
-  KGlobal::locale()->insertCatalogue("libkcddb");
-  setButtons(Default | Apply);
+  KGlobal::locale()->insertCatalog("libkcddb");
+  setButtons(Default | Apply | Help);
 
   widget_ = new CDDBConfigWidget(this);
 
@@ -58,7 +55,8 @@ CDDBModule::CDDBModule(QWidget *parent, const char *name, const QStringList &)
 
   addConfig(cfg, widget_);
 
-  QVBoxLayout * layout = new QVBoxLayout(this, 0);
+  QVBoxLayout * layout = new QVBoxLayout(this);
+  layout->setSpacing(0);
 
   layout->addWidget(widget_);
   layout->addStretch();
@@ -73,7 +71,8 @@ CDDBModule::defaults()
 {
   KCModule::defaults();
 
-  updateWidgetsFromConfig(KCDDB::Config());
+  KCDDB::Config config;
+  updateWidgetsFromConfig( config );
 }
 
   void
@@ -88,13 +87,13 @@ CDDBModule::checkSettings() const
       (!config.replyTo().isEmpty() && !config.replyTo().contains("@")))
       
   {
-    if (config.submitTransport() == KCDDB::Submit::SMTP)
+    if (config.freedbSubmitTransport() == KCDDB::Submit::SMTP)
     {
       KMessageBox::sorry(widget_, i18n("freedb has been set to use HTTP for submissions "
                                     "because the email details you have entered are "
                                     "incomplete. Please review your email settings "
                                     "and try again."), i18n("Incorrect Email Settings"));
-      config.setSubmitTransport(KCDDB::Submit::HTTP);
+      config.setFreedbSubmitTransport(KCDDB::Submit::HTTP);
 
       config.writeConfig();
     }
